@@ -8,6 +8,8 @@ from .consts import (
     HeaderKey,
     InternalEvents,
     Opcode,
+    OptKey,
+    ParallelMode,
     Probe,
     QueryParamKey,
     ServerKind,
@@ -62,7 +64,9 @@ __all__ = [
     "InBandSynchronizeResponse",
     "InternalEvents",
     "Opcode",
+    "OptKey",
     "PREFERRED_EXECUTION_VERSION",
+    "ParallelMode",
     "Priority",
     "Probe",
     "QueryParamKey",
